@@ -19,7 +19,7 @@
 
 =head1 NAME
 
-  DBIx::HTMLView::Id - A index filed used to identifi posts
+  DBIx::HTMLView::Id - A index field used to identify posts
 
 =head1 SYNOPSIS
 
@@ -28,21 +28,21 @@
 
 =head1 DESCRIPTION
 
-This is a subcalss of DBIx::HTMLView::Field used to represent the id
+This is a subclass of DBIx::HTMLView::Field used to represent the id
 fields of a table in the databse as well as the data contained in it. 
-Se the DBIx::HTMLView::Field and DBIx::HTMLView:.Fld (the superclass 
+See the DBIx::HTMLView::Field and DBIx::HTMLView:.Fld (the superclass 
 of Field) manpage for info on the methods of this class.
 
-Each post must have an unquire id number which the HTMLView system
+Each post must have an unique id number which the HTMLView system
 uses to identify the post. The id has to be stored in the database in
 a field which is specifyed by this class in the DBIx::HTMLView::Table
 object used to represent the table. There should only be one Id field.
 
-If you try to generat an html editor using the edit_html method this
+If you try to generate an html editor using the edit_html method this
 Fld will return a <input type=hidden ...> field that is used in the
-form to specify which post is beeing edited. 
+form to specify which post is being edited. 
 
-This behavour of not allowing the user to edit the id should probaly
+This behaviour of not allowing the user to edit the id should probably
 not be modified as the id might be stored in other places (for
 eaxample relations) too, and has to be updated there too.
 
@@ -55,15 +55,22 @@ use vars qw(@ISA);
 require DBIx::HTMLView::Int;
 @ISA = qw(DBIx::HTMLView::Int);
 
-sub edit_html {
-	my $self=shift;
-	if (defined $self->{'val'}) {
-		return $self->view_html.
-			'<input type=hidden name="'.$self->name.'" value="'.$self->val.'">';
-	} else {
-		return "";
-	}
+sub default_fmt {
+  my ($self, $kind)=@_;
+  if ($kind eq 'edit_html') {
+    return   $self->fmt('view_html') . 
+      '<perl>if ($self->got_val) { return ' .
+        '"<input type=hidden name=\"".$self->name . "\" value=\"".$self->var("val")."\">"' . 
+      '} </perl>';
+  }
+  return DBIx::HTMLView::Field::default_fmt(@_);
 }
 
 # FIXME: Make all Flds pass on ther $self vars like this
 sub sql_create {my $self=shift; $self->db->sql_type("Id",$self)}
+
+# Local Variables:
+# mode:              perl
+# tab-width:         8
+# perl-indent-level: 2
+# End:
